'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var pxToRem = require('../utils/px-to-rem.js');

const fontSizes = [12, 14, 15, 17, 20, 24, 28, 34, 42, 50, 70];
const fonts = {
    titlepiece: 'GT Guardian Titlepiece, Georgia, serif',
    headlineSerif: 'GH Guardian Headline, Guardian Egyptian Web, Georgia, serif',
    bodySerif: 'GuardianTextEgyptian, Guardian Text Egyptian Web, Georgia, serif',
    bodySans: 'GuardianTextSans, Guardian Text Sans Web, Helvetica Neue, Helvetica, Arial, Lucida Grande, sans-serif',
};
const lineHeights = [1.15, 1.35, 1.5];
const fontWeights = [300, 400, 500, 700];
const underlineThickness = [2, 3, 4, 5, 6];
const titlepieceSizes = {
    small: fontSizes[8],
    medium: fontSizes[9],
    large: fontSizes[10], //70px
};
const headlineSizes = {
    xxxsmall: fontSizes[3],
    xxsmall: fontSizes[4],
    xsmall: fontSizes[5],
    small: fontSizes[6],
    medium: fontSizes[7],
    large: fontSizes[8],
    xlarge: fontSizes[9], //50px
};
const bodySizes = {
    xsmall: fontSizes[1],
    small: fontSizes[2],
    medium: fontSizes[3], //17px
};
const textSansSizes = {
    xxsmall: fontSizes[0],
    xsmall: fontSizes[1],
    small: fontSizes[2],
    medium: fontSizes[3],
    large: fontSizes[4],
    xlarge: fontSizes[5],
    xxlarge: fontSizes[6],
    xxxlarge: fontSizes[7], //34px
};
const fontSizeMapping = {
    titlepiece: titlepieceSizes,
    headline: headlineSizes,
    body: bodySizes,
    textSans: textSansSizes,
};
const remFontSizes = fontSizes.map((fontSize) => pxToRem.pxToRem(fontSize));
const remTitlepieceSizes = {
    small: remFontSizes[8],
    medium: remFontSizes[9],
    large: remFontSizes[10], //70px
};
const remHeadlineSizes = {
    xxxsmall: remFontSizes[3],
    xxsmall: remFontSizes[4],
    xsmall: remFontSizes[5],
    small: remFontSizes[6],
    medium: remFontSizes[7],
    large: remFontSizes[8],
    xlarge: remFontSizes[9], //50px
};
const remBodySizes = {
    xsmall: remFontSizes[1],
    small: remFontSizes[2],
    medium: remFontSizes[3], //17px
};
const remTextSansSizes = {
    xxsmall: remFontSizes[0],
    xsmall: remFontSizes[1],
    small: remFontSizes[2],
    medium: remFontSizes[3],
    large: remFontSizes[4],
    xlarge: remFontSizes[5],
    xxlarge: remFontSizes[6],
    xxxlarge: remFontSizes[7], //34px
};
const remFontSizeMapping = {
    titlepiece: remTitlepieceSizes,
    headline: remHeadlineSizes,
    body: remBodySizes,
    textSans: remTextSansSizes,
};
const fontMapping = {
    titlepiece: fonts.titlepiece,
    headline: fonts.headlineSerif,
    body: fonts.bodySerif,
    textSans: fonts.bodySans,
};
const lineHeightMapping = {
    tight: lineHeights[0],
    regular: lineHeights[1],
    loose: lineHeights[2],
};
const fontWeightMapping = {
    light: fontWeights[0],
    regular: fontWeights[1],
    medium: fontWeights[2],
    bold: fontWeights[3],
};
const availableFonts = {
    titlepiece: {
        bold: {
            hasItalic: false,
        },
    },
    headline: {
        light: {
            hasItalic: true,
        },
        medium: {
            hasItalic: true,
        },
        bold: {
            hasItalic: false,
        },
    },
    body: {
        regular: {
            hasItalic: true,
        },
        bold: {
            hasItalic: true,
        },
    },
    textSans: {
        regular: {
            hasItalic: true,
        },
        bold: {
            hasItalic: false,
        },
    },
};
const titlepieceUnderlineThickness = {
    small: underlineThickness[3],
    medium: underlineThickness[4],
    large: underlineThickness[4], //6px
};
const headlineUnderlineThickness = {
    xxxsmall: underlineThickness[0],
    xxsmall: underlineThickness[1],
    xsmall: underlineThickness[1],
    small: underlineThickness[1],
    medium: underlineThickness[2],
    large: underlineThickness[3],
    xlarge: underlineThickness[4], //6px
};
const bodyUnderlineThickness = {
    xsmall: underlineThickness[0],
    small: underlineThickness[0],
    medium: underlineThickness[0], //2px
};
const textSansUnderlineThickness = {
    xxsmall: underlineThickness[0],
    xsmall: underlineThickness[0],
    small: underlineThickness[0],
    medium: underlineThickness[0],
    large: underlineThickness[1],
    xlarge: underlineThickness[1],
    xxlarge: underlineThickness[1],
    xxxlarge: underlineThickness[2], //4px
};
const underlineThicknessMapping = {
    titlepiece: titlepieceUnderlineThickness,
    headline: headlineUnderlineThickness,
    body: bodyUnderlineThickness,
    textSans: textSansUnderlineThickness,
};
Object.freeze(titlepieceSizes);
Object.freeze(headlineSizes);
Object.freeze(bodySizes);
Object.freeze(textSansSizes);
Object.freeze(remTitlepieceSizes);
Object.freeze(remHeadlineSizes);
Object.freeze(remBodySizes);
Object.freeze(remTextSansSizes);
Object.freeze(fontMapping);
Object.freeze(fontSizeMapping);
Object.freeze(fontWeightMapping);
Object.freeze(lineHeightMapping);
Object.freeze(availableFonts);
Object.freeze(titlepieceUnderlineThickness);
Object.freeze(headlineUnderlineThickness);
Object.freeze(bodyUnderlineThickness);
Object.freeze(textSansUnderlineThickness);
Object.freeze(underlineThicknessMapping);

exports.availableFonts = availableFonts;
exports.bodySizes = bodySizes;
exports.bodyUnderlineThickness = bodyUnderlineThickness;
exports.fontMapping = fontMapping;
exports.fontSizeMapping = fontSizeMapping;
exports.fontWeightMapping = fontWeightMapping;
exports.headlineSizes = headlineSizes;
exports.headlineUnderlineThickness = headlineUnderlineThickness;
exports.lineHeightMapping = lineHeightMapping;
exports.remBodySizes = remBodySizes;
exports.remFontSizeMapping = remFontSizeMapping;
exports.remFontSizes = remFontSizes;
exports.remHeadlineSizes = remHeadlineSizes;
exports.remTextSansSizes = remTextSansSizes;
exports.remTitlepieceSizes = remTitlepieceSizes;
exports.textSansSizes = textSansSizes;
exports.textSansUnderlineThickness = textSansUnderlineThickness;
exports.titlepieceSizes = titlepieceSizes;
exports.titlepieceUnderlineThickness = titlepieceUnderlineThickness;
exports.underlineThicknessMapping = underlineThicknessMapping;
//# sourceMappingURL=data.js.map
